@@ -25,8 +25,8 @@ class Parameter {
 private:
 	Parameter() {
 		window_thresh=10;//TODO check!
-		version="1.0.7";
-		huge_ins = 2000;//TODO check??
+		version="1.0.8";
+		huge_ins = 999;//TODO check??
 	}
 	~Parameter() {
 
@@ -81,6 +81,9 @@ public:
 	bool ignore_std;
 	bool reportBND;
 	bool print_seq;
+	bool change_coords; //indicating for --Ivcf
+	bool skip_parameter_estimation;
+	bool cs_string;
 
 	void set_regions(std::string reg) {
 		size_t i = 0;
