@@ -184,8 +184,7 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	}
 //Using PlaneSweep to comp coverage and iterate through reads:
 //PlaneSweep * sweep = new PlaneSweep();
-	std::cout << "Start parsing..." << std::endl;
-//Using Interval tree to store and manage breakpoints:
+	//Using Interval tree to store and manage breakpoints:
 
 	IntervallTree final;
 	IntervallTree bst;
@@ -207,6 +206,7 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	if (Parameter::Instance()->genotype) {
 		go = new Genotyper();
 	}*/
+	std::cout << "Start parsing... "<<ref[tmp_aln->getRefID()].RefName  << std::endl;
 
 	while (!tmp_aln->getQueryBases().empty()) {
 
@@ -249,6 +249,9 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 			std::vector<aln_str> split_events;
 			if (tmp_aln->getMappingQual() > Parameter::Instance()->min_mq) {
 				double score = tmp_aln->get_scrore_ratio();
+
+				//
+
 #pragma omp parallel // starts a new team
 				{
 #pragma omp sections
@@ -654,6 +657,9 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 }
 
 void estimate_parameters(std::string read_filename) {
+	if(Parameter::Instance()->skip_parameter_estimation){
+		return;
+	}
 	cout << "Estimating parameter..." << endl;
 	BamParser * mapped_file = 0;
 	RefVector ref;
